@@ -106,6 +106,7 @@ def find_prev_closest_time(prompt_time, subset_time_series):
 def match_feature(prompt_local_datetime_series, df_logs_combined):
     print("     --- start matching")
     matched_result_list = []
+    matched_time_list = []
 
     for idx in prompt_local_datetime_series.index:
         prompt_time = prompt_local_datetime_series[idx]
@@ -113,7 +114,8 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
 
 
         if df_logs_combined.shape[0] == 0:
-            location = np.nan
+            screen_status = np.nan
+            closest_time = np.nan
         else:
             subset_time_series = df_logs_combined["LOG_TIME_DATETIME"]
 
@@ -138,10 +140,10 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
                 else:
                     screen_status = np.nan
 
-
+        matched_time_list.append(closest_time)
         matched_result_list.append(screen_status)
 
-    return matched_result_list
+    return matched_result_list, matched_time_list
 
 
 def transform(screen_status_column):
@@ -157,12 +159,13 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
 
     if df_logs_combined.shape[0] > 0:
         # Match the combined parsed intermediate file with prompt feature data frame
-        result_column = match_feature(prompt_local_datetime_series, df_logs_combined)
+        result_column, match_time_screen = match_feature(prompt_local_datetime_series, df_logs_combined)
     else:
         result_column = ["NF"] * len(prompt_local_datetime_series)
+        match_time_screen = ["NF"] * len(prompt_local_datetime_series)
 
     # transform feature
     result_column_transformed = transform(result_column)
     print("     --- success")
 
-    return result_column_transformed
+    return result_column_transformed, match_time_screen
